
import { BrowserRouter as Router, Routes, Route, Navigate } from 'react-router-dom';
// Import all pages directly for instant loading
import Index from '@/pages/Index';
import About from '@/pages/About';
import AITools from '@/pages/AITools';
import AIToolPage from '@/pages/AIToolPage';
import ApplyNow from '@/pages/ApplyNow';
import Lab from '@/pages/Lab';
import Support from '@/pages/Support';
import AuthCallback from '@/pages/auth/callback';
import Privacy from '@/pages/Privacy';
import Terms from '@/pages/Terms';
import GetRoadmap from '@/pages/GetRoadmap';
import ExperimentPage from '@/pages/ExperimentPage';
import Survey from '@/pages/Survey';
import SurveyComplete from '@/pages/SurveyComplete';
import Settings from '@/pages/Settings';
import UpdatePassword from '@/pages/UpdatePassword';
import ResetPassword from '@/pages/ResetPassword';
import Partner from '@/pages/Partner';
import Launchpad from '@/pages/Launchpad';
import Audit from '@/pages/Audit';
import BusinessAudit from '@/pages/BusinessAudit';
import AuditFlow from '@/pages/AuditFlow';
import AuditResults from '@/components/audit/AuditResults';
import Workshop from '@/pages/Workshop';
import Login from '@/pages/Login';
import CalendarRedirect from '@/pages/CalendarRedirect';
import AdminRoutes from '@/components/admin/AdminRoutes';
import AdminExperimentEdit from '@/pages/AdminExperimentEdit';
import AdminExperimentCreate from '@/pages/AdminExperimentCreate';

import { Shell } from '@/components/Shell';
import { Toaster } from '@/components/ui/toaster';
import { AuthGuard } from './components/auth/AuthGuard';
import { CodeRedirector } from './components/auth/CodeRedirector';
import { AdminGuard } from './components/auth/AdminGuard';
import ScrollToTop from './components/ScrollToTop';
import { HelmetProvider } from 'react-helmet-async';
import { SecurityHeaders } from '@/components/security/SecurityHeaders';

function App() {
  return (
    <HelmetProvider>
      <Router>
        <SecurityHeaders />
        <ScrollToTop />
        <CodeRedirector />
        <Shell>
          <Routes>
            {/* All routes load instantly now */}
            <Route path="/" element={<Index />} />
            <Route path="about" element={<About />} />
            <Route path="ai-tools" element={<AITools />} />
            <Route path="lab" element={<Lab />} />
            <Route path="auth" element={<Login />} />
            <Route path="auth/callback" element={<AuthCallback />} />
            <Route path="update-password" element={<UpdatePassword />} />
            <Route path="reset-password" element={<ResetPassword />} />
            <Route path="login" element={<Navigate to="/auth" replace />} />
            <Route path="apply" element={<ApplyNow />} />
            <Route path="ai-tools/:slug" element={<AIToolPage />} />
            <Route path="privacy" element={<Privacy />} />
            <Route path="terms" element={<Terms />} />
            <Route path="roadmap" element={<GetRoadmap />} />
            <Route path="support" element={<Support />} />
            <Route path="survey" element={<Survey />} />
            <Route path="survey/complete" element={<SurveyComplete />} />
            <Route path="partner" element={<Partner />} />
            <Route path="launchpad" element={<Launchpad />} />
            <Route path="audit" element={<Audit />} />
            <Route path="business-audit" element={<BusinessAudit />} />
            <Route path="business-audit/flow" element={<AuditFlow />} />
            <Route path="business-audit/results" element={<AuditResults />} />
            <Route path="free-vibe-coding-course" element={<Workshop />} />
            <Route path="lab/:slug" element={<ExperimentPage />} />
            <Route path="workshop" element={<Navigate to="/free-vibe-coding-course" replace />} />
            
            {/* Calendar routes for email links */}
            <Route path="/calendar/:calendarType" element={<CalendarRedirect />} />
            
            {/* Protected routes */}
            <Route element={<AuthGuard>{null}</AuthGuard>}>
              <Route path="settings" element={<Settings />} />
              <Route path="admin/*" element={
                <AdminGuard>
                  <AdminRoutes />
                </AdminGuard>
              } />
            </Route>
          </Routes>
        </Shell>
        <Toaster />
      </Router>
    </HelmetProvider>
  );
}

export default App;
